componenttools.split_components_once_by_prolated_durations_and_fracture_crossing_spanners
=========================================================================================

.. autofunction:: abjad.tools.componenttools.split_components_once_by_prolated_durations_and_fracture_crossing_spanners
